@@ -212,7 +212,7 @@ namespace FLAC {
 			return object_->type;
 		}
 
-		unsigned Prototype::get_length() const
+		uint32_t Prototype::get_length() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->length;
@@ -236,43 +236,43 @@ namespace FLAC {
 		StreamInfo::~StreamInfo()
 		{ }
 
-		unsigned StreamInfo::get_min_blocksize() const
+		uint32_t StreamInfo::get_min_blocksize() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.stream_info.min_blocksize;
 		}
 
-		unsigned StreamInfo::get_max_blocksize() const
+		uint32_t StreamInfo::get_max_blocksize() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.stream_info.max_blocksize;
 		}
 
-		unsigned StreamInfo::get_min_framesize() const
+		uint32_t StreamInfo::get_min_framesize() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.stream_info.min_framesize;
 		}
 
-		unsigned StreamInfo::get_max_framesize() const
+		uint32_t StreamInfo::get_max_framesize() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.stream_info.max_framesize;
 		}
 
-		unsigned StreamInfo::get_sample_rate() const
+		uint32_t StreamInfo::get_sample_rate() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.stream_info.sample_rate;
 		}
 
-		unsigned StreamInfo::get_channels() const
+		uint32_t StreamInfo::get_channels() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.stream_info.channels;
 		}
 
-		unsigned StreamInfo::get_bits_per_sample() const
+		uint32_t StreamInfo::get_bits_per_sample() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.stream_info.bits_per_sample;
@@ -290,7 +290,7 @@ namespace FLAC {
 			return object_->data.stream_info.md5sum;
 		}
 
-		void StreamInfo::set_min_blocksize(unsigned value)
+		void StreamInfo::set_min_blocksize(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(value >= FLAC__MIN_BLOCK_SIZE);
@@ -298,7 +298,7 @@ namespace FLAC {
 			object_->data.stream_info.min_blocksize = value;
 		}
 
-		void StreamInfo::set_max_blocksize(unsigned value)
+		void StreamInfo::set_max_blocksize(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(value >= FLAC__MIN_BLOCK_SIZE);
@@ -306,28 +306,28 @@ namespace FLAC {
 			object_->data.stream_info.max_blocksize = value;
 		}
 
-		void StreamInfo::set_min_framesize(unsigned value)
+		void StreamInfo::set_min_framesize(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(value < (1u << FLAC__STREAM_METADATA_STREAMINFO_MIN_FRAME_SIZE_LEN));
 			object_->data.stream_info.min_framesize = value;
 		}
 
-		void StreamInfo::set_max_framesize(unsigned value)
+		void StreamInfo::set_max_framesize(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(value < (1u << FLAC__STREAM_METADATA_STREAMINFO_MAX_FRAME_SIZE_LEN));
 			object_->data.stream_info.max_framesize = value;
 		}
 
-		void StreamInfo::set_sample_rate(unsigned value)
+		void StreamInfo::set_sample_rate(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(FLAC__format_sample_rate_is_valid(value));
 			object_->data.stream_info.sample_rate = value;
 		}
 
-		void StreamInfo::set_channels(unsigned value)
+		void StreamInfo::set_channels(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(value > 0);
@@ -335,7 +335,7 @@ namespace FLAC {
 			object_->data.stream_info.channels = value;
 		}
 
-		void StreamInfo::set_bits_per_sample(unsigned value)
+		void StreamInfo::set_bits_per_sample(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(value >= FLAC__MIN_BITS_PER_SAMPLE);
@@ -366,7 +366,7 @@ namespace FLAC {
 		Prototype(FLAC__metadata_object_new(FLAC__METADATA_TYPE_PADDING), /*copy=*/false)
 		{ }
 
-		Padding::Padding(unsigned length):
+		Padding::Padding(uint32_t length):
 		Prototype(FLAC__metadata_object_new(FLAC__METADATA_TYPE_PADDING), /*copy=*/false)
 		{
 			set_length(length);
@@ -375,7 +375,7 @@ namespace FLAC {
 		Padding::~Padding()
 		{ }
 
-		void Padding::set_length(unsigned length)
+		void Padding::set_length(uint32_t length)
 		{
 			FLAC__ASSERT(is_valid());
 			object_->length = length;
@@ -412,13 +412,13 @@ namespace FLAC {
 			memcpy(object_->data.application.id, value, 4);
 		}
 
-		bool Application::set_data(const FLAC__byte *data, unsigned length)
+		bool Application::set_data(const FLAC__byte *data, uint32_t length)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_application_set_data(object_, (FLAC__byte*)data, length, true);
 		}
 
-		bool Application::set_data(FLAC__byte *data, unsigned length, bool copy)
+		bool Application::set_data(FLAC__byte *data, uint32_t length, bool copy)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_application_set_data(object_, data, length, copy);
@@ -436,40 +436,40 @@ namespace FLAC {
 		SeekTable::~SeekTable()
 		{ }
 
-		unsigned SeekTable::get_num_points() const
+		uint32_t SeekTable::get_num_points() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.seek_table.num_points;
 		}
 
-		::FLAC__StreamMetadata_SeekPoint SeekTable::get_point(unsigned indx) const
+		::FLAC__StreamMetadata_SeekPoint SeekTable::get_point(uint32_t indx) const
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx < object_->data.seek_table.num_points);
 			return object_->data.seek_table.points[indx];
 		}
 
-		bool SeekTable::resize_points(unsigned new_num_points)
+		bool SeekTable::resize_points(uint32_t new_num_points)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_seektable_resize_points(object_, new_num_points);
 		}
 
-		void SeekTable::set_point(unsigned indx, const ::FLAC__StreamMetadata_SeekPoint &point)
+		void SeekTable::set_point(uint32_t indx, const ::FLAC__StreamMetadata_SeekPoint &point)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx < object_->data.seek_table.num_points);
 			::FLAC__metadata_object_seektable_set_point(object_, indx, point);
 		}
 
-		bool SeekTable::insert_point(unsigned indx, const ::FLAC__StreamMetadata_SeekPoint &point)
+		bool SeekTable::insert_point(uint32_t indx, const ::FLAC__StreamMetadata_SeekPoint &point)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx <= object_->data.seek_table.num_points);
 			return (bool)::FLAC__metadata_object_seektable_insert_point(object_, indx, point);
 		}
 
-		bool SeekTable::delete_point(unsigned indx)
+		bool SeekTable::delete_point(uint32_t indx)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx < object_->data.seek_table.num_points);
@@ -482,7 +482,7 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_seektable_is_legal(object_);
 		}
 
-		bool SeekTable::template_append_placeholders(unsigned num)
+		bool SeekTable::template_append_placeholders(uint32_t num)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_seektable_template_append_placeholders(object_, num);
@@ -494,19 +494,19 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_seektable_template_append_point(object_, sample_number);
 		}
 
-		bool SeekTable::template_append_points(FLAC__uint64 sample_numbers[], unsigned num)
+		bool SeekTable::template_append_points(FLAC__uint64 sample_numbers[], uint32_t num)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_seektable_template_append_points(object_, sample_numbers, num);
 		}
 
-		bool SeekTable::template_append_spaced_points(unsigned num, FLAC__uint64 total_samples)
+		bool SeekTable::template_append_spaced_points(uint32_t num, FLAC__uint64 total_samples)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_seektable_template_append_spaced_points(object_, num, total_samples);
 		}
 
-		bool SeekTable::template_append_spaced_points_by_samples(unsigned samples, FLAC__uint64 total_samples)
+		bool SeekTable::template_append_spaced_points_by_samples(uint32_t samples, FLAC__uint64 total_samples)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_seektable_template_append_spaced_points_by_samples(object_, samples, total_samples);
@@ -534,7 +534,7 @@ namespace FLAC {
 			zero();
 		}
 
-		VorbisComment::Entry::Entry(const char *field, unsigned field_length) :
+		VorbisComment::Entry::Entry(const char *field, uint32_t field_length) :
 			is_valid_(true),
 			entry_(),
 			field_name_(0),
@@ -558,7 +558,7 @@ namespace FLAC {
 			construct(field);
 		}
 
-		VorbisComment::Entry::Entry(const char *field_name, const char *field_value, unsigned field_value_length) :
+		VorbisComment::Entry::Entry(const char *field_name, const char *field_value, uint32_t field_value_length) :
 			is_valid_(true),
 			entry_(),
 			field_name_(0),
@@ -613,19 +613,19 @@ namespace FLAC {
 			return is_valid_;
 		}
 
-		unsigned VorbisComment::Entry::get_field_length() const
+		uint32_t VorbisComment::Entry::get_field_length() const
 		{
 			FLAC__ASSERT(is_valid());
 			return entry_.length;
 		}
 
-		unsigned VorbisComment::Entry::get_field_name_length() const
+		uint32_t VorbisComment::Entry::get_field_name_length() const
 		{
 			FLAC__ASSERT(is_valid());
 			return field_name_length_;
 		}
 
-		unsigned VorbisComment::Entry::get_field_value_length() const
+		uint32_t VorbisComment::Entry::get_field_value_length() const
 		{
 			FLAC__ASSERT(is_valid());
 			return field_value_length_;
@@ -655,7 +655,7 @@ namespace FLAC {
 			return field_value_;
 		}
 
-		bool VorbisComment::Entry::set_field(const char *field, unsigned field_length)
+		bool VorbisComment::Entry::set_field(const char *field, uint32_t field_length)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(0 != field);
@@ -704,7 +704,7 @@ namespace FLAC {
 			return is_valid_;
 		}
 
-		bool VorbisComment::Entry::set_field_value(const char *field_value, unsigned field_value_length)
+		bool VorbisComment::Entry::set_field_value(const char *field_value, uint32_t field_value_length)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(0 != field_value);
@@ -778,7 +778,7 @@ namespace FLAC {
 			}
 		}
 
-		void VorbisComment::Entry::construct(const char *field, unsigned field_length)
+		void VorbisComment::Entry::construct(const char *field, uint32_t field_length)
 		{
 			if(set_field(field, field_length))
 				parse_field();
@@ -789,7 +789,7 @@ namespace FLAC {
 			construct(field, strlen(field));
 		}
 
-		void VorbisComment::Entry::construct(const char *field_name, const char *field_value, unsigned field_value_length)
+		void VorbisComment::Entry::construct(const char *field_name, const char *field_value, uint32_t field_value_length)
 		{
 			if(set_field_name(field_name) && set_field_value(field_value, field_value_length))
 				compose_field();
@@ -830,7 +830,7 @@ namespace FLAC {
 			if(0 == p)
 				p = (const char *)entry_.entry + entry_.length;
 
-			field_name_length_ = (unsigned)(p - (const char *)entry_.entry);
+			field_name_length_ = (uint32_t)(p - (const char *)entry_.entry);
 			if(0 == (field_name_ = (char *)safe_malloc_add_2op_(field_name_length_, /*+*/1))) { // +1 for the trailing \0
 				is_valid_ = false;
 				return;
@@ -870,7 +870,7 @@ namespace FLAC {
 		VorbisComment::~VorbisComment()
 		{ }
 
-		unsigned VorbisComment::get_num_comments() const
+		uint32_t VorbisComment::get_num_comments() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.vorbis_comment.num_comments;
@@ -882,7 +882,7 @@ namespace FLAC {
 			return object_->data.vorbis_comment.vendor_string.entry;
 		}
 
-		VorbisComment::Entry VorbisComment::get_comment(unsigned indx) const
+		VorbisComment::Entry VorbisComment::get_comment(uint32_t indx) const
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx < object_->data.vorbis_comment.num_comments);
@@ -897,20 +897,20 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_vorbiscomment_set_vendor_string(object_, vendor_string, /*copy=*/true);
 		}
 
-		bool VorbisComment::resize_comments(unsigned new_num_comments)
+		bool VorbisComment::resize_comments(uint32_t new_num_comments)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_vorbiscomment_resize_comments(object_, new_num_comments);
 		}
 
-		bool VorbisComment::set_comment(unsigned indx, const VorbisComment::Entry &entry)
+		bool VorbisComment::set_comment(uint32_t indx, const VorbisComment::Entry &entry)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx < object_->data.vorbis_comment.num_comments);
 			return (bool)::FLAC__metadata_object_vorbiscomment_set_comment(object_, indx, entry.get_entry(), /*copy=*/true);
 		}
 
-		bool VorbisComment::insert_comment(unsigned indx, const VorbisComment::Entry &entry)
+		bool VorbisComment::insert_comment(uint32_t indx, const VorbisComment::Entry &entry)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx <= object_->data.vorbis_comment.num_comments);
@@ -929,14 +929,14 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_vorbiscomment_replace_comment(object_, entry.get_entry(), all, /*copy=*/true);
 		}
 
-		bool VorbisComment::delete_comment(unsigned indx)
+		bool VorbisComment::delete_comment(uint32_t indx)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(indx < object_->data.vorbis_comment.num_comments);
 			return (bool)::FLAC__metadata_object_vorbiscomment_delete_comment(object_, indx);
 		}
 
-		int VorbisComment::find_entry_from(unsigned offset, const char *field_name)
+		int VorbisComment::find_entry_from(uint32_t offset, const char *field_name)
 		{
 			FLAC__ASSERT(is_valid());
 			return ::FLAC__metadata_object_vorbiscomment_find_entry_from(object_, offset, field_name);
@@ -990,7 +990,7 @@ namespace FLAC {
 			return(0 != object_);
 		}
 
-		::FLAC__StreamMetadata_CueSheet_Index CueSheet::Track::get_index(unsigned i) const
+		::FLAC__StreamMetadata_CueSheet_Index CueSheet::Track::get_index(uint32_t i) const
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(i < object_->num_indices);
@@ -1005,14 +1005,14 @@ namespace FLAC {
 			object_->isrc[12] = '\0';
 		}
 
-		void CueSheet::Track::set_type(unsigned value)
+		void CueSheet::Track::set_type(uint32_t value)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(value <= 1);
 			object_->type = value;
 		}
 
- 		void CueSheet::Track::set_index(unsigned i, const ::FLAC__StreamMetadata_CueSheet_Index &indx)
+ 		void CueSheet::Track::set_index(uint32_t i, const ::FLAC__StreamMetadata_CueSheet_Index &indx)
  		{
  			FLAC__ASSERT(is_valid());
  			FLAC__ASSERT(i < object_->num_indices);
@@ -1049,13 +1049,13 @@ namespace FLAC {
 			return object_->data.cue_sheet.is_cd? true : false;
 		}
 
-		unsigned CueSheet::get_num_tracks() const
+		uint32_t CueSheet::get_num_tracks() const
 		{
 			FLAC__ASSERT(is_valid());
 			return object_->data.cue_sheet.num_tracks;
 		}
 
-		CueSheet::Track CueSheet::get_track(unsigned i) const
+		CueSheet::Track CueSheet::get_track(uint32_t i) const
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(i < object_->data.cue_sheet.num_tracks);
@@ -1082,7 +1082,7 @@ namespace FLAC {
 			object_->data.cue_sheet.is_cd = value;
 		}
 
-		void CueSheet::set_index(unsigned track_num, unsigned index_num, const ::FLAC__StreamMetadata_CueSheet_Index &indx)
+		void CueSheet::set_index(uint32_t track_num, uint32_t index_num, const ::FLAC__StreamMetadata_CueSheet_Index &indx)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(track_num < object_->data.cue_sheet.num_tracks);
@@ -1090,14 +1090,14 @@ namespace FLAC {
 			object_->data.cue_sheet.tracks[track_num].indices[index_num] = indx;
 		}
 
-		bool CueSheet::resize_indices(unsigned track_num, unsigned new_num_indices)
+		bool CueSheet::resize_indices(uint32_t track_num, uint32_t new_num_indices)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(track_num < object_->data.cue_sheet.num_tracks);
 			return (bool)::FLAC__metadata_object_cuesheet_track_resize_indices(object_, track_num, new_num_indices);
 		}
 
-		bool CueSheet::insert_index(unsigned track_num, unsigned index_num, const ::FLAC__StreamMetadata_CueSheet_Index &indx)
+		bool CueSheet::insert_index(uint32_t track_num, uint32_t index_num, const ::FLAC__StreamMetadata_CueSheet_Index &indx)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(track_num < object_->data.cue_sheet.num_tracks);
@@ -1105,7 +1105,7 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_cuesheet_track_insert_index(object_, track_num, index_num, indx);
 		}
 
-		bool CueSheet::insert_blank_index(unsigned track_num, unsigned index_num)
+		bool CueSheet::insert_blank_index(uint32_t track_num, uint32_t index_num)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(track_num < object_->data.cue_sheet.num_tracks);
@@ -1113,7 +1113,7 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_cuesheet_track_insert_blank_index(object_, track_num, index_num);
 		}
 
-		bool CueSheet::delete_index(unsigned track_num, unsigned index_num)
+		bool CueSheet::delete_index(uint32_t track_num, uint32_t index_num)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(track_num < object_->data.cue_sheet.num_tracks);
@@ -1121,13 +1121,13 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_cuesheet_track_delete_index(object_, track_num, index_num);
 		}
 
-		bool CueSheet::resize_tracks(unsigned new_num_tracks)
+		bool CueSheet::resize_tracks(uint32_t new_num_tracks)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_cuesheet_resize_tracks(object_, new_num_tracks);
 		}
 
-		bool CueSheet::set_track(unsigned i, const CueSheet::Track &track)
+		bool CueSheet::set_track(uint32_t i, const CueSheet::Track &track)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(i < object_->data.cue_sheet.num_tracks);
@@ -1135,7 +1135,7 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_cuesheet_set_track(object_, i, const_cast< ::FLAC__StreamMetadata_CueSheet_Track*>(track.get_track()), /*copy=*/true);
 		}
 
-		bool CueSheet::insert_track(unsigned i, const CueSheet::Track &track)
+		bool CueSheet::insert_track(uint32_t i, const CueSheet::Track &track)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(i <= object_->data.cue_sheet.num_tracks);
@@ -1143,14 +1143,14 @@ namespace FLAC {
 			return (bool)::FLAC__metadata_object_cuesheet_insert_track(object_, i, const_cast< ::FLAC__StreamMetadata_CueSheet_Track*>(track.get_track()), /*copy=*/true);
 		}
 
-		bool CueSheet::insert_blank_track(unsigned i)
+		bool CueSheet::insert_blank_track(uint32_t i)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(i <= object_->data.cue_sheet.num_tracks);
 			return (bool)::FLAC__metadata_object_cuesheet_insert_blank_track(object_, i);
 		}
 
-		bool CueSheet::delete_track(unsigned i)
+		bool CueSheet::delete_track(uint32_t i)
 		{
 			FLAC__ASSERT(is_valid());
 			FLAC__ASSERT(i < object_->data.cue_sheet.num_tracks);
@@ -1310,13 +1310,13 @@ namespace FLAC {
 			return object_->data.application.data;
 		}
 
-		bool Unknown::set_data(const FLAC__byte *data, unsigned length)
+		bool Unknown::set_data(const FLAC__byte *data, uint32_t length)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_application_set_data(object_, (FLAC__byte*)data, length, true);
 		}
 
-		bool Unknown::set_data(FLAC__byte *data, unsigned length, bool copy)
+		bool Unknown::set_data(FLAC__byte *data, uint32_t length, bool copy)
 		{
 			FLAC__ASSERT(is_valid());
 			return (bool)::FLAC__metadata_object_application_set_data(object_, data, length, copy);
@@ -1403,7 +1403,7 @@ namespace FLAC {
 				return false;
 		}
 
-		FLACPP_API bool get_picture(const char *filename, Picture *&picture, ::FLAC__StreamMetadata_Picture_Type type, const char *mime_type, const FLAC__byte *description, unsigned max_width, unsigned max_height, unsigned max_depth, unsigned max_colors)
+		FLACPP_API bool get_picture(const char *filename, Picture *&picture, ::FLAC__StreamMetadata_Picture_Type type, const char *mime_type, const FLAC__byte *description, uint32_t max_width, uint32_t max_height, uint32_t max_depth, uint32_t max_colors)
 		{
 			FLAC__ASSERT(0 != filename);
 
@@ -1419,7 +1419,7 @@ namespace FLAC {
 				return false;
 		}
 
-		FLACPP_API bool get_picture(const char *filename, Picture &picture, ::FLAC__StreamMetadata_Picture_Type type, const char *mime_type, const FLAC__byte *description, unsigned max_width, unsigned max_height, unsigned max_depth, unsigned max_colors)
+		FLACPP_API bool get_picture(const char *filename, Picture &picture, ::FLAC__StreamMetadata_Picture_Type type, const char *mime_type, const FLAC__byte *description, uint32_t max_width, uint32_t max_height, uint32_t max_depth, uint32_t max_colors)
 		{
 			FLAC__ASSERT(0 != filename);
 
@@ -1513,7 +1513,7 @@ namespace FLAC {
 		}
 
 		//@@@@ add to tests
-		unsigned SimpleIterator::get_block_length() const
+		uint32_t SimpleIterator::get_block_length() const
 		{
 			FLAC__ASSERT(is_valid());
 			return ::FLAC__metadata_simple_iterator_get_block_length(iterator_);
