@@ -47,18 +47,15 @@
 
 #include <emmintrin.h> /* SSE2 */
 
-#define RESIDUAL16_RESULT(xmmN) curr = *data++; *residual++ = curr - (_mm_cvtsi128_si32(xmmN) >> lp_quantization);
-#define     DATA16_RESULT(xmmN) curr = *residual++ + (_mm_cvtsi128_si32(xmmN) >> lp_quantization); *data++ = curr;
-
 #define RESIDUAL32_RESULT(xmmN) residual[i] = data[i] - (_mm_cvtsi128_si32(xmmN) >> lp_quantization);
 #define     DATA32_RESULT(xmmN) data[i] = residual[i] + (_mm_cvtsi128_si32(xmmN) >> lp_quantization);
 
 FLAC__SSE_TARGET("sse2")
-void FLAC__lpc_compute_residual_from_qlp_coefficients_16_intrin_sse2(const FLAC__int32 *data, unsigned data_len, const FLAC__int32 qlp_coeff[], unsigned order, int lp_quantization, FLAC__int32 residual[])
+void FLAC__lpc_compute_residual_from_qlp_coefficients_16_intrin_sse2(const FLAC__int32 *data, uint32_t data_len, const FLAC__int32 qlp_coeff[], uint32_t order, int lp_quantization, FLAC__int32 residual[])
 {
 	int i;
 	FLAC__int32 sum;
-	__m128i cnt = _mm_cvtsi32_si128(lp_quantization);
+	const __m128i cnt = _mm_cvtsi32_si128(lp_quantization);
 
 	FLAC__ASSERT(order > 0);
 	FLAC__ASSERT(order <= 32);
@@ -349,17 +346,17 @@ void FLAC__lpc_compute_residual_from_qlp_coefficients_16_intrin_sse2(const FLAC_
 		for(; i < (int)data_len; i++) {
 			sum = 0;
 			switch(order) {
-				case 12: sum += qlp_coeff[11] * data[i-12];
-				case 11: sum += qlp_coeff[10] * data[i-11];
-				case 10: sum += qlp_coeff[ 9] * data[i-10];
-				case 9:  sum += qlp_coeff[ 8] * data[i- 9];
-				case 8:  sum += qlp_coeff[ 7] * data[i- 8];
-				case 7:  sum += qlp_coeff[ 6] * data[i- 7];
-				case 6:  sum += qlp_coeff[ 5] * data[i- 6];
-				case 5:  sum += qlp_coeff[ 4] * data[i- 5];
-				case 4:  sum += qlp_coeff[ 3] * data[i- 4];
-				case 3:  sum += qlp_coeff[ 2] * data[i- 3];
-				case 2:  sum += qlp_coeff[ 1] * data[i- 2];
+				case 12: sum += qlp_coeff[11] * data[i-12]; /* Falls through. */
+				case 11: sum += qlp_coeff[10] * data[i-11]; /* Falls through. */
+				case 10: sum += qlp_coeff[ 9] * data[i-10]; /* Falls through. */
+				case 9:  sum += qlp_coeff[ 8] * data[i- 9]; /* Falls through. */
+				case 8:  sum += qlp_coeff[ 7] * data[i- 8]; /* Falls through. */
+				case 7:  sum += qlp_coeff[ 6] * data[i- 7]; /* Falls through. */
+				case 6:  sum += qlp_coeff[ 5] * data[i- 6]; /* Falls through. */
+				case 5:  sum += qlp_coeff[ 4] * data[i- 5]; /* Falls through. */
+				case 4:  sum += qlp_coeff[ 3] * data[i- 4]; /* Falls through. */
+				case 3:  sum += qlp_coeff[ 2] * data[i- 3]; /* Falls through. */
+				case 2:  sum += qlp_coeff[ 1] * data[i- 2]; /* Falls through. */
 				case 1:  sum += qlp_coeff[ 0] * data[i- 1];
 			}
 			residual[i] = data[i] - (sum >> lp_quantization);
@@ -369,25 +366,25 @@ void FLAC__lpc_compute_residual_from_qlp_coefficients_16_intrin_sse2(const FLAC_
 		for(i = 0; i < (int)data_len; i++) {
 			sum = 0;
 			switch(order) {
-				case 32: sum += qlp_coeff[31] * data[i-32];
-				case 31: sum += qlp_coeff[30] * data[i-31];
-				case 30: sum += qlp_coeff[29] * data[i-30];
-				case 29: sum += qlp_coeff[28] * data[i-29];
-				case 28: sum += qlp_coeff[27] * data[i-28];
-				case 27: sum += qlp_coeff[26] * data[i-27];
-				case 26: sum += qlp_coeff[25] * data[i-26];
-				case 25: sum += qlp_coeff[24] * data[i-25];
-				case 24: sum += qlp_coeff[23] * data[i-24];
-				case 23: sum += qlp_coeff[22] * data[i-23];
-				case 22: sum += qlp_coeff[21] * data[i-22];
-				case 21: sum += qlp_coeff[20] * data[i-21];
-				case 20: sum += qlp_coeff[19] * data[i-20];
-				case 19: sum += qlp_coeff[18] * data[i-19];
-				case 18: sum += qlp_coeff[17] * data[i-18];
-				case 17: sum += qlp_coeff[16] * data[i-17];
-				case 16: sum += qlp_coeff[15] * data[i-16];
-				case 15: sum += qlp_coeff[14] * data[i-15];
-				case 14: sum += qlp_coeff[13] * data[i-14];
+				case 32: sum += qlp_coeff[31] * data[i-32]; /* Falls through. */
+				case 31: sum += qlp_coeff[30] * data[i-31]; /* Falls through. */
+				case 30: sum += qlp_coeff[29] * data[i-30]; /* Falls through. */
+				case 29: sum += qlp_coeff[28] * data[i-29]; /* Falls through. */
+				case 28: sum += qlp_coeff[27] * data[i-28]; /* Falls through. */
+				case 27: sum += qlp_coeff[26] * data[i-27]; /* Falls through. */
+				case 26: sum += qlp_coeff[25] * data[i-26]; /* Falls through. */
+				case 25: sum += qlp_coeff[24] * data[i-25]; /* Falls through. */
+				case 24: sum += qlp_coeff[23] * data[i-24]; /* Falls through. */
+				case 23: sum += qlp_coeff[22] * data[i-23]; /* Falls through. */
+				case 22: sum += qlp_coeff[21] * data[i-22]; /* Falls through. */
+				case 21: sum += qlp_coeff[20] * data[i-21]; /* Falls through. */
+				case 20: sum += qlp_coeff[19] * data[i-20]; /* Falls through. */
+				case 19: sum += qlp_coeff[18] * data[i-19]; /* Falls through. */
+				case 18: sum += qlp_coeff[17] * data[i-18]; /* Falls through. */
+				case 17: sum += qlp_coeff[16] * data[i-17]; /* Falls through. */
+				case 16: sum += qlp_coeff[15] * data[i-16]; /* Falls through. */
+				case 15: sum += qlp_coeff[14] * data[i-15]; /* Falls through. */
+				case 14: sum += qlp_coeff[13] * data[i-14]; /* Falls through. */
 				case 13: sum += qlp_coeff[12] * data[i-13];
 				         sum += qlp_coeff[11] * data[i-12];
 				         sum += qlp_coeff[10] * data[i-11];
@@ -408,7 +405,7 @@ void FLAC__lpc_compute_residual_from_qlp_coefficients_16_intrin_sse2(const FLAC_
 }
 
 FLAC__SSE_TARGET("sse2")
-void FLAC__lpc_compute_residual_from_qlp_coefficients_intrin_sse2(const FLAC__int32 *data, unsigned data_len, const FLAC__int32 qlp_coeff[], unsigned order, int lp_quantization, FLAC__int32 residual[])
+void FLAC__lpc_compute_residual_from_qlp_coefficients_intrin_sse2(const FLAC__int32 *data, uint32_t data_len, const FLAC__int32 qlp_coeff[], uint32_t order, int lp_quantization, FLAC__int32 residual[])
 {
 	int i;
 
@@ -896,25 +893,25 @@ void FLAC__lpc_compute_residual_from_qlp_coefficients_intrin_sse2(const FLAC__in
 		for(i = 0; i < (int)data_len; i++) {
 			sum = 0;
 			switch(order) {
-				case 32: sum += qlp_coeff[31] * data[i-32];
-				case 31: sum += qlp_coeff[30] * data[i-31];
-				case 30: sum += qlp_coeff[29] * data[i-30];
-				case 29: sum += qlp_coeff[28] * data[i-29];
-				case 28: sum += qlp_coeff[27] * data[i-28];
-				case 27: sum += qlp_coeff[26] * data[i-27];
-				case 26: sum += qlp_coeff[25] * data[i-26];
-				case 25: sum += qlp_coeff[24] * data[i-25];
-				case 24: sum += qlp_coeff[23] * data[i-24];
-				case 23: sum += qlp_coeff[22] * data[i-23];
-				case 22: sum += qlp_coeff[21] * data[i-22];
-				case 21: sum += qlp_coeff[20] * data[i-21];
-				case 20: sum += qlp_coeff[19] * data[i-20];
-				case 19: sum += qlp_coeff[18] * data[i-19];
-				case 18: sum += qlp_coeff[17] * data[i-18];
-				case 17: sum += qlp_coeff[16] * data[i-17];
-				case 16: sum += qlp_coeff[15] * data[i-16];
-				case 15: sum += qlp_coeff[14] * data[i-15];
-				case 14: sum += qlp_coeff[13] * data[i-14];
+				case 32: sum += qlp_coeff[31] * data[i-32]; /* Falls through. */
+				case 31: sum += qlp_coeff[30] * data[i-31]; /* Falls through. */
+				case 30: sum += qlp_coeff[29] * data[i-30]; /* Falls through. */
+				case 29: sum += qlp_coeff[28] * data[i-29]; /* Falls through. */
+				case 28: sum += qlp_coeff[27] * data[i-28]; /* Falls through. */
+				case 27: sum += qlp_coeff[26] * data[i-27]; /* Falls through. */
+				case 26: sum += qlp_coeff[25] * data[i-26]; /* Falls through. */
+				case 25: sum += qlp_coeff[24] * data[i-25]; /* Falls through. */
+				case 24: sum += qlp_coeff[23] * data[i-24]; /* Falls through. */
+				case 23: sum += qlp_coeff[22] * data[i-23]; /* Falls through. */
+				case 22: sum += qlp_coeff[21] * data[i-22]; /* Falls through. */
+				case 21: sum += qlp_coeff[20] * data[i-21]; /* Falls through. */
+				case 20: sum += qlp_coeff[19] * data[i-20]; /* Falls through. */
+				case 19: sum += qlp_coeff[18] * data[i-19]; /* Falls through. */
+				case 18: sum += qlp_coeff[17] * data[i-18]; /* Falls through. */
+				case 17: sum += qlp_coeff[16] * data[i-17]; /* Falls through. */
+				case 16: sum += qlp_coeff[15] * data[i-16]; /* Falls through. */
+				case 15: sum += qlp_coeff[14] * data[i-15]; /* Falls through. */
+				case 14: sum += qlp_coeff[13] * data[i-14]; /* Falls through. */
 				case 13: sum += qlp_coeff[12] * data[i-13];
 				         sum += qlp_coeff[11] * data[i-12];
 				         sum += qlp_coeff[10] * data[i-11];
@@ -934,156 +931,6 @@ void FLAC__lpc_compute_residual_from_qlp_coefficients_intrin_sse2(const FLAC__in
 	}
 }
 
-#if defined FLAC__CPU_IA32 && !defined FLAC__HAS_NASM /* unused for x64; not better than MMX asm */
-
-FLAC__SSE_TARGET("sse2")
-void FLAC__lpc_restore_signal_16_intrin_sse2(const FLAC__int32 residual[], unsigned data_len, const FLAC__int32 qlp_coeff[], unsigned order, int lp_quantization, FLAC__int32 data[])
-{
-	if (order < 8 || order > 12) {
-		FLAC__lpc_restore_signal(residual, data_len, qlp_coeff, order, lp_quantization, data);
-		return;
-	}
-	if (data_len == 0)
-		return;
-
-	FLAC__ASSERT(order >= 8);
-	FLAC__ASSERT(order <= 12);
-
-	if(order > 8) { /* order == 9, 10, 11, 12 */
-		FLAC__int32 curr;
-		__m128i xmm0, xmm1, xmm2, xmm3, xmm4, xmm5, xmm6, xmm7;
-		xmm0 = _mm_loadu_si128((const __m128i*)(qlp_coeff+0));
-		xmm6 = _mm_loadu_si128((const __m128i*)(qlp_coeff+4));
-		xmm1 = _mm_loadu_si128((const __m128i*)(qlp_coeff+8)); /* read 0 to 3 uninitialized coeffs... */
-		switch(order)                                          /* ...and zero them out */
-		{
-		case 9:
-			xmm1 = _mm_slli_si128(xmm1, 12); xmm1 = _mm_srli_si128(xmm1, 12); break;
-		case 10:
-			xmm1 = _mm_slli_si128(xmm1, 8); xmm1 = _mm_srli_si128(xmm1, 8); break;
-		case 11:
-			xmm1 = _mm_slli_si128(xmm1, 4); xmm1 = _mm_srli_si128(xmm1, 4); break;
-		}
-		xmm2 = _mm_setzero_si128();
-		xmm0 = _mm_packs_epi32(xmm0, xmm6);
-		xmm1 = _mm_packs_epi32(xmm1, xmm2);
-
-		xmm4 = _mm_loadu_si128((const __m128i*)(data-12));
-		xmm5 = _mm_loadu_si128((const __m128i*)(data-8));
-		xmm3 = _mm_loadu_si128((const __m128i*)(data-4));
-		xmm4 = _mm_shuffle_epi32(xmm4, _MM_SHUFFLE(0,1,2,3));
-		xmm5 = _mm_shuffle_epi32(xmm5, _MM_SHUFFLE(0,1,2,3));
-		xmm3 = _mm_shuffle_epi32(xmm3, _MM_SHUFFLE(0,1,2,3));
-		xmm4 = _mm_packs_epi32(xmm4, xmm2);
-		xmm3 = _mm_packs_epi32(xmm3, xmm5);
-
-		xmm7 = _mm_slli_si128(xmm1, 2);
-		xmm7 = _mm_or_si128(xmm7, _mm_srli_si128(xmm0, 14));
-		xmm2 = _mm_slli_si128(xmm0, 2);
-
-		/* xmm0, xmm1: qlp_coeff
-			xmm2, xmm7: qlp_coeff << 16 bit
-			xmm3, xmm4: data */
-
-		xmm5 = _mm_madd_epi16(xmm4, xmm1);
-		xmm6 = _mm_madd_epi16(xmm3, xmm0);
-		xmm6 = _mm_add_epi32(xmm6, xmm5);
-		xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 8));
-		xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 4));
-
-		DATA16_RESULT(xmm6);
-
-		data_len--;
-
-		if(data_len % 2) {
-			xmm6 = _mm_srli_si128(xmm3, 14);
-			xmm4 = _mm_slli_si128(xmm4, 2);
-			xmm3 = _mm_slli_si128(xmm3, 2);
-			xmm4 = _mm_or_si128(xmm4, xmm6);
-			xmm3 = _mm_insert_epi16(xmm3, curr, 0);
-
-			xmm5 = _mm_madd_epi16(xmm4, xmm1);
-			xmm6 = _mm_madd_epi16(xmm3, xmm0);
-			xmm6 = _mm_add_epi32(xmm6, xmm5);
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 8));
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 4));
-
-			DATA16_RESULT(xmm6);
-
-			data_len--;
-		}
-
-		while(data_len) { /* data_len is a multiple of 2 */
-			/* 1 _mm_slli_si128 per data element less but we need shifted qlp_coeff in xmm2:xmm7 */
-			xmm6 = _mm_srli_si128(xmm3, 12);
-			xmm4 = _mm_slli_si128(xmm4, 4);
-			xmm3 = _mm_slli_si128(xmm3, 4);
-			xmm4 = _mm_or_si128(xmm4, xmm6);
-			xmm3 = _mm_insert_epi16(xmm3, curr, 1);
-
-			xmm5 = _mm_madd_epi16(xmm4, xmm7);
-			xmm6 = _mm_madd_epi16(xmm3, xmm2);
-			xmm6 = _mm_add_epi32(xmm6, xmm5);
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 8));
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 4));
-
-			DATA16_RESULT(xmm6);
-
-			xmm3 = _mm_insert_epi16(xmm3, curr, 0);
-
-			xmm5 = _mm_madd_epi16(xmm4, xmm1);
-			xmm6 = _mm_madd_epi16(xmm3, xmm0);
-			xmm6 = _mm_add_epi32(xmm6, xmm5);
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 8));
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 4));
-
-			DATA16_RESULT(xmm6);
-
-			data_len-=2;
-		}
-	} /* endif(order > 8) */
-	else
-	{
-		FLAC__int32 curr;
-		__m128i xmm0, xmm1, xmm3, xmm6;
-		xmm0 = _mm_loadu_si128((const __m128i*)(qlp_coeff+0));
-		xmm1 = _mm_loadu_si128((const __m128i*)(qlp_coeff+4));
-		xmm0 = _mm_packs_epi32(xmm0, xmm1);
-
-		xmm1 = _mm_loadu_si128((const __m128i*)(data-8));
-		xmm3 = _mm_loadu_si128((const __m128i*)(data-4));
-		xmm1 = _mm_shuffle_epi32(xmm1, _MM_SHUFFLE(0,1,2,3));
-		xmm3 = _mm_shuffle_epi32(xmm3, _MM_SHUFFLE(0,1,2,3));
-		xmm3 = _mm_packs_epi32(xmm3, xmm1);
-
-		/* xmm0: qlp_coeff
-			xmm3: data */
-
-		xmm6 = _mm_madd_epi16(xmm3, xmm0);
-		xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 8));
-		xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 4));
-
-		DATA16_RESULT(xmm6);
-
-		data_len--;
-
-		while(data_len) {
-			xmm3 = _mm_slli_si128(xmm3, 2);
-			xmm3 = _mm_insert_epi16(xmm3, curr, 0);
-
-			xmm6 = _mm_madd_epi16(xmm3, xmm0);
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 8));
-			xmm6 = _mm_add_epi32(xmm6, _mm_srli_si128(xmm6, 4));
-
-			DATA16_RESULT(xmm6);
-
-			data_len--;
-		}
-	}
-}
-
-#endif /* defined FLAC__CPU_IA32 && !defined FLAC__HAS_NASM */
-
 #endif /* FLAC__SSE2_SUPPORTED */
 #endif /* (FLAC__CPU_IA32 || FLAC__CPU_X86_64) && FLAC__HAS_X86INTRIN */
 #endif /* FLAC__NO_ASM */
